@@ -16,7 +16,7 @@ def is_healthy():
             content = file.read()
             timestamp, timeout = content.split(',')
             if time() > int(timestamp) + int(timeout):
-                print('Unhealthy')
+                exit(1)
     
     except FileNotFoundError as e:
         print('Healthcheck file not found', flush=True)
